@@ -17,30 +17,23 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from gi.repository import Gtk
-from gi.repository import Gdk
-from gi.repository import Pango
 import cgi
+import logging
 import urllib.parse
 
-import logging
-logger = logging.getLogger(__name__)
+from gi.repository import Gdk, Gtk, Pango
 
 import gpodder
+from gpodder import util, vimeo, youtube
+from gpodder.gtkui.desktopfile import PlayerListModel
+from gpodder.gtkui.interface.common import BuilderWidget, TreeViewHelper
+from gpodder.gtkui.interface.configeditor import gPodderConfigEditor
+
+logger = logging.getLogger(__name__)
 
 _ = gpodder.gettext
 N_ = gpodder.ngettext
 
-from gpodder import util
-from gpodder import youtube
-from gpodder import vimeo
-
-from gpodder.gtkui.interface.common import BuilderWidget
-from gpodder.gtkui.interface.common import TreeViewHelper
-from gpodder.gtkui.interface.configeditor import gPodderConfigEditor
-
-from gpodder.gtkui.desktopfile import PlayerListModel
-
 
 class NewEpisodeActionList(Gtk.ListStore):
     C_CAPTION, C_AUTO_DOWNLOAD = list(range(2))
@@ -123,7 +116,7 @@ class YouTubeVideoFormatListModel(Gtk.ListStore):
 
         if self._config.youtube.preferred_fmt_ids:
             caption = _('Custom (%(format_ids)s)') % {
-                    'format_ids': ', '.join(str(x) for x in self.custom_fmt_ids),
+                'format_ids': ', '.join(str(x) for x in self.custom_fmt_ids),
             }
             self.append((caption, -1))
 
@@ -342,7 +335,8 @@ class gPodderPreferences(BuilderWidget):
                 yield (container.metadata.category, container)
 
         old_category = None
-        for category, container in sorted(convert(gpodder.user_extensions.get_extensions()), key=key_func):
+        for category, container in sorted(convert(
+                gpodder.user_extensions.get_extensions()), key=key_func):
             if old_category != category:
                 label = '<span weight="bold">%s</span>' % cgi.escape(category)
                 self.extensions_model.append((None, label, None, False))
@@ -438,8 +432,8 @@ class gPodderPreferences(BuilderWidget):
         # This is one ugly hack, but it displays the attributes of
         # the metadata object of the container..
         info = '\n'.join('<b>%s:</b> %s' %
-                tuple(map(cgi.escape, list(map(str, (key, value)))))
-                for key, value in container.metadata.get_sorted())
+                         tuple(map(cgi.escape, list(map(str, (key, value)))))
+                         for key, value in container.metadata.get_sorted())
 
         self.show_message(info, _('Extension module info'), important=True)
 
@@ -479,8 +473,8 @@ class gPodderPreferences(BuilderWidget):
 
     def on_button_audio_player_clicked(self, widget):
         result = self.show_text_edit_dialog(_('Configure audio player'),
-                _('Command:'),
-                self._config.player)
+                                            _('Command:'),
+                                            self._config.player)
 
         if result:
             self._config.player = result
@@ -489,8 +483,8 @@ class gPodderPreferences(BuilderWidget):
 
     def on_button_video_player_clicked(self, widget):
         result = self.show_text_edit_dialog(_('Configure video player'),
-                _('Command:'),
-                self._config.videoplayer)
+                                            _('Command:'),
+                                            self._config.videoplayer)
 
         if result:
             self._config.videoplayer = result
@@ -527,7 +521,8 @@ class gPodderPreferences(BuilderWidget):
         if value == 0:
             return _('manually')
         else:
-            return N_('after %(count)d day', 'after %(count)d days', value) % {'count':value}
+            return N_('after %(count)d day', 'after %(count)d days',
+                      value) % {'count': value}
 
     def on_expiration_value_changed(self, range):
         value = int(range.get_value())
@@ -579,7 +574,8 @@ class gPodderPreferences(BuilderWidget):
         index = self.combobox_on_sync.get_active()
         self.on_sync_model.set_index(index)
 
-    def on_checkbutton_create_playlists_toggled(self, widget,device_type_changed=False):
+    def on_checkbutton_create_playlists_toggled(
+            self, widget, device_type_changed=False):
         if not widget.get_active():
             self._config.device_sync.playlists.create = False
             self.toggle_playlist_interface(False)
