@@ -187,6 +187,11 @@ class SoundcloudUser(object):
 class SoundcloudFeed(object):
     URL_REGEX = re.compile('https?://([a-z]+\.)?soundcloud\.com/([^/]+)$', re.I)
 
+    @classmethod
+    def fetch_channel(cls, channel, max_episodes=0):
+        url = channel.authenticate_url(channel.url)
+        return cls.handle_url(url)
+
     @classmethod
     def handle_url(cls, url):
         m = cls.URL_REGEX.match(url)
